instrumenttools.Tuba
====================

.. abjad-lineage:: abjad.tools.instrumenttools.Tuba.Tuba

.. autoclass:: abjad.tools.instrumenttools.Tuba.Tuba

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.instrumenttools.Tuba.Tuba.allowable_clefs
      ~abjad.tools.instrumenttools.Tuba.Tuba.instrument_name
      ~abjad.tools.instrumenttools.Tuba.Tuba.instrument_name_markup
      ~abjad.tools.instrumenttools.Tuba.Tuba.pitch_range
      ~abjad.tools.instrumenttools.Tuba.Tuba.short_instrument_name
      ~abjad.tools.instrumenttools.Tuba.Tuba.short_instrument_name_markup
      ~abjad.tools.instrumenttools.Tuba.Tuba.sounding_pitch_of_written_middle_c
      ~abjad.tools.instrumenttools.Tuba.Tuba.__copy__
      ~abjad.tools.instrumenttools.Tuba.Tuba.__eq__
      ~abjad.tools.instrumenttools.Tuba.Tuba.__format__
      ~abjad.tools.instrumenttools.Tuba.Tuba.__hash__
      ~abjad.tools.instrumenttools.Tuba.Tuba.__ne__
      ~abjad.tools.instrumenttools.Tuba.Tuba.__repr__

Bases
-----

- :py:class:`instrumenttools.Instrument <abjad.tools.instrumenttools.Instrument.Instrument>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.allowable_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Tuba.Tuba.sounding_pitch_of_written_middle_c
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.__copy__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.__format__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Tuba.Tuba.__repr__
   :noindex:
